/*
 *  Copyright (c) 2017, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.wso2.carbon.uuf.sample.featuresapp.bundle;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardCopyOption;

/**
 * Uses file related operations.
 *
 * @since 1.0.0
 */
public class FileUtils {

    /**
     * Copies the given file to the temp directory.
     *
     * @param filePath location of the source file
     * @return the destination of the file path after copying or null if an error occur
     */
    public static String copy(String filePath, String fileName) throws IOException {
        String tempDirPath = System.getProperty("java.io.tmpdir");
        Path destination = Paths.get(tempDirPath).resolve(fileName);
        Path sourcePath = Paths.get(filePath);

        //copy the selected file to UUF_HOME/tmp directory overriding any existing content with the same name
        Files.copy(sourcePath, destination, StandardCopyOption.REPLACE_EXISTING);
        return tempDirPath;
    }
}
